[java-metadata-aggregator] branch main updated: MDA-245 - Terminology changes

Ian Young ian at iay.org.uk
Wed May 8 16:23:51 UTC 2024


This is an automated email from the git hooks/post-receive script.

iay pushed a commit to branch main
in repository java-metadata-aggregator.

View the commit online:
http://git.shibboleth.net/view/?p=java-metadata-aggregator.git;a=commit;h=6db90c6b2fc48378111419bc5220efbc44f83578

The following commit(s) were added to refs/heads/main by this push:
     new 6db90c6  MDA-245 - Terminology changes
6db90c6 is described below

commit 6db90c6b2fc48378111419bc5220efbc44f83578
Author: Ian Young <ian at iay.org.uk>
AuthorDate: Wed May 8 17:23:47 2024 +0100

    MDA-245 - Terminology changes
    
    https://shibboleth.atlassian.net/browse/MDA-245
---
 ...or.java => X509RSAOpenSSLKeylistValidator.java} | 90 +++++++++++++++-------
 .../resources/net/shibboleth/metadata/beans.xml    |  9 ++-
 ...ava => X509RSAOpenSSLKeylistValidatorTest.java} | 90 ++++++++++++++--------
 .../x509/testing/BaseX509ValidatorTest.java        |  6 +-
 .../shibboleth/metadata/dom/MDA125Test-config.xml  |  4 +-
 ...pem => X509RSAOpenSSLKeylistValidator-1024.pem} |  0
 ...txt => X509RSAOpenSSLKeylistValidator-1024.txt} |  0
 ...pem => X509RSAOpenSSLKeylistValidator-2048.pem} |  0
 ...txt => X509RSAOpenSSLKeylistValidator-2048.txt} |  0
 ...t => X509RSAOpenSSLKeylistValidator-issue9.txt} |  0
 ...k.pem => X509RSAOpenSSLKeylistValidator-ok.pem} |  0
 11 files changed, 133 insertions(+), 66 deletions(-)

diff --git a/mda-framework/src/main/resources/net/shibboleth/metadata/beans.xml b/mda-framework/src/main/resources/net/shibboleth/metadata/beans.xml
index ddc7f10..8aa44e2 100644
--- a/mda-framework/src/main/resources/net/shibboleth/metadata/beans.xml
+++ b/mda-framework/src/main/resources/net/shibboleth/metadata/beans.xml
@@ -379,8 +379,8 @@
     <bean id="mda.X509RSAKeyLengthValidator" abstract="true" parent="mda.validator_parent"
         class="net.shibboleth.metadata.validate.x509.X509RSAKeyLengthValidator"/>
 
-    <bean id="mda.X509RSAOpenSSLBlacklistValidator" abstract="true" parent="mda.validator_parent"
-        class="net.shibboleth.metadata.validate.x509.X509RSAOpenSSLBlacklistValidator"/>
+    <bean id="mda.X509RSAOpenSSLKeylistValidator" abstract="true" parent="mda.validator_parent"
+        class="net.shibboleth.metadata.validate.x509.X509RSAOpenSSLKeylistValidator"/>
 
     <!--
         ***********************************************************
@@ -456,6 +456,8 @@
              value="net.shibboleth.metadata.dom.saml.CRDetectionStage"/>
         <entry key="net.shibboleth.metadata.util.PKCS11PrivateKeyFactoryBean"
              value="net.shibboleth.shared.spring.security.factory.PKCS11PrivateKeyFactoryBean"/>
+        <entry key="net.shibboleth.metadata.validate.x509.X509RSAOpenSSLBlacklistValidator"
+             value="net.shibboleth.metadata.validate.x509.X509RSAOpenSSLKeylistValidator"/>
 
         <!-- Classes from spring-extensions in MDA 0.9, not in MDA 0.10. -->
         <entry key="net.shibboleth.ext.spring.config.BooleanToPredicateConverter"
@@ -502,6 +504,9 @@
 
     <util:map id="mda.MigrationBeanMap">
 
+        <!-- Changes from 0.9 to 0.10 -->
+        <entry key="mda.X509RSAOpenSSLBlacklistValidator"   value="mda.X509RSAOpenSSLKeylistValidator"/>
+
         <!-- Beans adopted from ukf-mda project in MDA 0.10.0. -->
         <entry key="ukf.AssuranceCertificationMatcher"      value="mda.AssuranceCertificationMatcher"/>
         <entry key="ukf.DiscoFeedCollectionSerializer"      value="mda.DiscoFeedCollectionSerializer"/>
diff --git a/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidatorTest.java b/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidatorTest.java
similarity index 68%
rename from mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidatorTest.java
rename to mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidatorTest.java
index dd40c0e..7166236 100644
--- a/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidatorTest.java
+++ b/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidatorTest.java
@@ -28,15 +28,15 @@ import net.shibboleth.metadata.validate.Validator;
 import net.shibboleth.metadata.validate.x509.testing.BaseX509ValidatorTest;
 import net.shibboleth.shared.component.ComponentInitializationException;
 
-public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest {
+public class X509RSAOpenSSLKeylistValidatorTest extends BaseX509ValidatorTest {
     
-    public X509RSAOpenSSLBlacklistValidatorTest() throws Exception {
-        super(X509RSAOpenSSLBlacklistValidator.class);
+    public X509RSAOpenSSLKeylistValidatorTest() throws Exception {
+        super(X509RSAOpenSSLKeylistValidator.class);
     }
 
     @Test
-    public void testNotBlacklisted() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
+    public void testNotBadLegacy() throws Exception {
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
         val.setBlacklistResource(getClasspathResource("1024.txt"));
         val.setId("test");
         val.initialize();
@@ -49,10 +49,38 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
         val.destroy();
     }
 
+    @Test
+    public void testGetResourceLegacy() throws Exception {
+        final var val = new X509RSAOpenSSLKeylistValidator();
+        val.setId("test");
+        Assert.assertNull(val.getBlacklistResource());
+        final var resource = getClasspathResource("1024.txt");
+        Assert.assertNotNull(resource);
+        val.setBlacklistResource(resource);
+        Assert.assertSame(val.getBlacklistResource(), resource);
+        val.initialize();
+        val.destroy();
+    }
+
+    @Test
+    public void testNotBad() throws Exception {
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("1024.txt"));
+        val.setId("test");
+        val.initialize();
+        Assert.assertEquals(val.getKeySize(), 0); // no key size restriction
+        
+        final Item<String> item = new MockItem("foo");
+        final X509Certificate cert = getCertificate("ok.pem");
+        Assert.assertEquals(val.validate(cert, item, "stage"), Validator.Action.CONTINUE);
+        errorsAndWarnings(item, 0, 0);
+        val.destroy();
+    }
+
     @Test
     public void test1024on1024noRestriction() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("1024.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("1024.txt"));
         val.setId("test");
         val.initialize();
         Assert.assertEquals(val.getKeySize(), 0); // no key size restriction
@@ -66,8 +94,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void test1024on1024Restricted() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("1024.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("1024.txt"));
         val.setKeySize(1024);
         val.setId("test");
         val.initialize();
@@ -81,8 +109,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void test1024on1024Restricted2() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("1024.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("1024.txt"));
         val.setKeySize(2048); // untrue, but should prevent any matches
         val.setId("test");
         val.initialize();
@@ -96,8 +124,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void test2048on1024noRestriction() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("1024.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("1024.txt"));
         val.setId("test");
         val.initialize();
         Assert.assertEquals(val.getKeySize(), 0); // no key size restriction
@@ -111,8 +139,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void test2048on2048noRestriction() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("2048.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("2048.txt"));
         val.setId("test");
         val.initialize();
         Assert.assertEquals(val.getKeySize(), 0); // no key size restriction
@@ -126,8 +154,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void test2048on2048Restricted() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("2048.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("2048.txt"));
         val.setKeySize(2048);
         val.setId("test");
         val.initialize();
@@ -141,8 +169,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void test2048on2048Restricted2() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("2048.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("2048.txt"));
         val.setKeySize(1024); // untrue, but should prevent any matches
         val.setId("test");
         val.initialize();
@@ -156,8 +184,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void testBlankLineIssue9() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(getClasspathResource("issue9.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(getClasspathResource("issue9.txt"));
         val.setId("test");
         val.initialize();
         val.destroy();
@@ -165,17 +193,17 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void mda198() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
         // do not initialize
         Assert.assertNull(val.getId(), "unset ID should be null");
     }
 
     @Test
     public void mda219() throws Exception {
-        final var val = new X509RSAOpenSSLBlacklistValidator();
+        final var val = new X509RSAOpenSSLKeylistValidator();
         final var resource = getClasspathResource("does-not-exist.txt");
         val.setId("test");
-        val.setBlacklistResource(resource);
+        val.setKeylistResource(resource);
         try {
             val.initialize();
             Assert.fail("expected exception");
@@ -191,20 +219,20 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
     
     @Test
     public void testGetResource() throws Exception {
-        final var val = new X509RSAOpenSSLBlacklistValidator();
+        final var val = new X509RSAOpenSSLKeylistValidator();
         val.setId("test");
-        Assert.assertNull(val.getBlacklistResource());
+        Assert.assertNull(val.getKeylistResource());
         final var resource = getClasspathResource("1024.txt");
         Assert.assertNotNull(resource);
-        val.setBlacklistResource(resource);
-        Assert.assertSame(val.getBlacklistResource(), resource);
+        val.setKeylistResource(resource);
+        Assert.assertSame(val.getKeylistResource(), resource);
         val.initialize();
         val.destroy();
     }
 
     @Test(expectedExceptions = ComponentInitializationException.class)
     public void testNoResource() throws Exception {
-        final var val = new X509RSAOpenSSLBlacklistValidator();
+        final var val = new X509RSAOpenSSLKeylistValidator();
         val.setId("test");
         val.initialize();
     }
@@ -212,8 +240,8 @@ public class X509RSAOpenSSLBlacklistValidatorTest extends BaseX509ValidatorTest
 
     @Test
     public void classPathResource() throws Exception {
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
-        val.setBlacklistResource(new ClassPathResource("net/shibboleth/metadata/keylists/rsa/debian-2048.txt"));
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
+        val.setKeylistResource(new ClassPathResource("net/shibboleth/metadata/keylists/rsa/debian-2048.txt"));
         val.setKeySize(2048);
         val.setId("test");
         val.initialize();
diff --git a/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/testing/BaseX509ValidatorTest.java b/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/testing/BaseX509ValidatorTest.java
index 45ba73c..6702baf 100644
--- a/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/testing/BaseX509ValidatorTest.java
+++ b/mda-framework/src/test/java/net/shibboleth/metadata/validate/x509/testing/BaseX509ValidatorTest.java
@@ -39,7 +39,7 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
 import net.shibboleth.metadata.testing.BaseTest;
 import net.shibboleth.metadata.testing.MockItem;
 import net.shibboleth.metadata.validate.Validator;
-import net.shibboleth.metadata.validate.x509.X509RSAOpenSSLBlacklistValidator;
+import net.shibboleth.metadata.validate.x509.X509RSAOpenSSLKeylistValidator;
 
 public abstract class BaseX509ValidatorTest extends BaseTest {
     
@@ -109,9 +109,9 @@ public abstract class BaseX509ValidatorTest extends BaseTest {
         }
     
         // create a validator
-        final X509RSAOpenSSLBlacklistValidator val = new X509RSAOpenSSLBlacklistValidator();
+        final X509RSAOpenSSLKeylistValidator val = new X509RSAOpenSSLKeylistValidator();
         val.setId("validator-" + keySize);
-        val.setBlacklistResource(keylistResource);
+        val.setKeylistResource(keylistResource);
         val.setKeySize(keySize);
         val.initialize();
     
diff --git a/mda-framework/src/test/resources/net/shibboleth/metadata/dom/MDA125Test-config.xml b/mda-framework/src/test/resources/net/shibboleth/metadata/dom/MDA125Test-config.xml
index 546d0be..adf772c 100644
--- a/mda-framework/src/test/resources/net/shibboleth/metadata/dom/MDA125Test-config.xml
+++ b/mda-framework/src/test/resources/net/shibboleth/metadata/dom/MDA125Test-config.xml
@@ -18,12 +18,12 @@
     
     <bean id="XMLSignatureValidationStage" abstract="true" parent="stage_parent"
         class="net.shibboleth.metadata.dom.XMLSignatureValidationStage">
-        <property name="blacklistedDigests">
+        <property name="disallowedDigests">
             <list>
                 <value>http://www.w3.org/2001/04/xmldsig-more#md5</value>
             </list>
         </property>
-        <property name="blacklistedSignatureMethods">
+        <property name="disallowedSignatureMethods">
             <list>
                 <value>http://www.w3.org/2001/04/xmldsig-more#rsa-md5</value>
             </list>
diff --git a/mda-framework/src/main/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator.java b/mda-framework/src/main/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator.java
similarity index 71%
rename from mda-framework/src/main/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator.java
rename to mda-framework/src/main/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator.java
index d1f5e22..a3c1332 100644
--- a/mda-framework/src/main/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator.java
+++ b/mda-framework/src/main/java/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator.java
@@ -41,54 +41,88 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.logic.Constraint;
+import net.shibboleth.shared.primitive.DeprecationSupport;
+import net.shibboleth.shared.primitive.DeprecationSupport.ObjectType;
 
 /**
  * Validator class to check RSA moduli in X.509 certificates against a OpenSSL-format
  * blacklist. Appropriate blacklists are available as part of the Debian 7.x
  * openssl-blacklist and openssl-blacklist-extra packages.
  *
- * @since 0.9.0
+ * @since 0.10.0
  */
 @ThreadSafe
-public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
+public class X509RSAOpenSSLKeylistValidator extends AbstractX509Validator {
     
     /** Sequence of bytes put on the front of the string to be hashed. */
     private static final byte[] OPEN_SSL_PREFIX = {
             'M', 'o', 'd', 'u', 'l', 'u', 's', '=',
     };
     
     /** Resource that provides the blacklist. */
     @NonnullAfterInit @GuardedBy("this")
-    private Resource blacklistResource;
+    private Resource keylistResource;
     
     /** Restrict checking to a given key size. Default: no restriction (0). */
     @GuardedBy("this") private int keySize;
 
-    /** Set of digest values blacklisted by this validator. */
+    /** Set of digest values checked by this validator. */
     @Nonnull @GuardedBy("this")
-    private final Set<String> blacklistedValues = new HashSet<>();
+    private final Set<String> digestValues = new HashSet<>();
 
     /**
      * Gets the resource that provides the blacklist.
      * 
-     * @return resource that provides the blacklist
+     * @return resource that provides the keylist
+     * 
+     * @since 0.10.0
+     */
+    @NonnullAfterInit public final synchronized Resource getKeylistResource() {
+        return keylistResource;
+    }
+
+    /**
+     * Sets the resource that provides the keylist.
+     * 
+     * @param resource resource that provides the keylist
+     * 
+     * @since 0.10.0
      */
+    public synchronized void setKeylistResource(@Nonnull final Resource resource) {
+        checkSetterPreconditions();
+        keylistResource = Constraint.isNotNull(resource, "keylist resource can not be null");
+    }
+    
+    /**
+     * Gets the resource that provides the keylist.
+     * 
+     * @return resource that provides the keylist
+     */
+    @Deprecated(since="0.10.0", forRemoval=true)
     @NonnullAfterInit public final synchronized Resource getBlacklistResource() {
-        return blacklistResource;
+        DeprecationSupport.warnOnce(ObjectType.METHOD, "getBlacklistResource",
+                "X509RSAOpenSSLKeylistValidator", "getKeylistResource");
+        return getKeylistResource();
     }
 
     /**
      * Sets the resource that provides the blacklist.
      * 
      * @param resource resource that provides the blacklist
      */
+    @Deprecated(since="0.10.0", forRemoval=true)
     public synchronized void setBlacklistResource(@Nonnull final Resource resource) {
-        checkSetterPreconditions();
-        blacklistResource = Constraint.isNotNull(resource, "blacklist resource can not be null");
+        DeprecationSupport.warnOnce(ObjectType.METHOD, "setBlacklistResource",
+                "X509RSAOpenSSLKeylistValidator", "setKeylistResource");
+        setKeylistResource(resource);
     }
     
     /**
      * Sets a key size restriction for this blacklist.
      * 
      * @param size restricted key size, or 0 for no restriction
      */
@@ -97,9 +131,9 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
     }
     
     /**
      * Gets the key size restriction for this blacklist.
      * 
      * @return restricted key size for this blacklist, or 0 if no restriction
      */
     public final synchronized int getKeySize() {
         return keySize;
@@ -109,7 +143,7 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
      * Computes the OpenSSL digest value for the given modulus.
      * 
      * @param modulus RSA public modulus to be digested
      * @return value to be compared against the blacklist
      * @throws StageProcessingException if SHA1 digester can not be acquired, or for internal
      *      errors related to {@link ByteArrayOutputStream}
      */
@@ -170,14 +204,14 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
             final Set<String> values;
             final int keySz;
             synchronized (this) {
-                values = blacklistedValues;
+                values = digestValues;
                 keySz = keySize;
             }
 
             if (keySz == 0 || keySz == modulus.bitLength()) {
                 final String value = openSSLDigest(modulus);
                 if (values.contains(value)) {
-                    addError("RSA modulus included in key blacklist (" + value + ")",
+                    addError("RSA modulus included in key list (" + value + ")",
                             item, callerId);
                 }
             }
@@ -187,7 +221,7 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
     @Override
     protected void doDestroy() {
         // We don't need references to the individual values any more.
-        blacklistedValues.clear();
+        digestValues.clear();
 
         super.doDestroy();
     }
@@ -196,13 +230,13 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
     protected void doInitialize() throws ComponentInitializationException {
         super.doInitialize();
 
-        if (blacklistResource == null) {
+        if (keylistResource == null) {
             throw new ComponentInitializationException("Unable to initialize " + getId()
-                    + ", blacklistResource must not be null");
+                    + ", keylistResource must not be null");
         }
 
         try (BufferedReader reader =
-                new BufferedReader(new InputStreamReader(blacklistResource.getInputStream(), StandardCharsets.UTF_8))) {
+                new BufferedReader(new InputStreamReader(keylistResource.getInputStream(), StandardCharsets.UTF_8))) {
             while (true) {
                 final String line = reader.readLine();
                 if (line == null) {
@@ -216,12 +250,12 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
                 
                 // Ignore comments.
                 if (line.charAt(0) != '#') {
-                    blacklistedValues.add(line);
+                    digestValues.add(line);
                 }
             }
         } catch (final IOException e) {
             throw new ComponentInitializationException("Unable to initialize " + getId()
-                    + ", error reading blacklistResource " + blacklistResource.getDescription() + " information", e);
+                    + ", error reading keylistResource " + keylistResource.getDescription() + " information", e);
         }
 
     }
@@ -41,54 +41,88 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
 
 /**
- * Validator class to check RSA moduli in X.509 certificates against a OpenSSL-format
- * blacklist. Appropriate blacklists are available as part of the Debian 7.x
- * openssl-blacklist and openssl-blacklist-extra packages.
+ * Validator class to check RSA moduli in X.509 certificates against a list of
+ * OpenSSL-format keys.
+ * 
+ * <p>
+ * Appropriate lists are available as part of the
+ * {@code mda-keylists-rsa} and {@code mda-keylists-rsa-legacy} modules.
+ * </p>
  *
@@ -41,54 +41,88 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
     };
     
-    /** Resource that provides the blacklist. */
+    /** Resource that provides the list of keys. */
     @NonnullAfterInit @GuardedBy("this")
@@ -41,54 +41,88 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
 
     /**
-     * Gets the resource that provides the blacklist.
+     * Gets the resource that provides the keylist.
      * 
@@ -41,54 +41,88 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
 
     /**
-     * Sets the resource that provides the blacklist.
+     * Sets the resource that provides the keylist.
      * 
@@ -41,54 +41,88 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
      * 
-     * @param resource resource that provides the blacklist
+     * @param resource resource that provides the keylist
      */
@@ -41,54 +41,88 @@ import net.shibboleth.metadata.pipeline.StageProcessingException;
     
     /**
-     * Sets a key size restriction for this blacklist.
+     * Sets a key size restriction for this list.
      * 
      * @param size restricted key size, or 0 for no restriction
@@ -97,9 +131,9 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
     
     /**
-     * Gets the key size restriction for this blacklist.
+     * Gets the key size restriction for this list.
      * 
@@ -97,9 +131,9 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
      * 
-     * @return restricted key size for this blacklist, or 0 if no restriction
+     * @return restricted key size for this list, or 0 if no restriction
      */
     public final synchronized int getKeySize() {
@@ -109,7 +143,7 @@ public class X509RSAOpenSSLBlacklistValidator extends AbstractX509Validator {
      * 
      * @param modulus RSA public modulus to be digested
-     * @return value to be compared against the blacklist
+     * @return value to be compared against the list
      * @throws StageProcessingException if SHA1 digester can not be acquired, or for internal
      *      errors related to {@link ByteArrayOutputStream}
diff --git a/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-1024.pem b/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-1024.pem
similarity index 100%
rename from mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-1024.pem
rename to mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-1024.pem
diff --git a/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-1024.txt b/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-1024.txt
similarity index 100%
rename from mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-1024.txt
rename to mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-1024.txt
diff --git a/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-2048.pem b/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-2048.pem
similarity index 100%
rename from mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-2048.pem
rename to mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-2048.pem
diff --git a/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-2048.txt b/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-2048.txt
similarity index 100%
rename from mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-2048.txt
rename to mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-2048.txt
diff --git a/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-issue9.txt b/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-issue9.txt
similarity index 100%
rename from mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-issue9.txt
rename to mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-issue9.txt
diff --git a/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-ok.pem b/mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-ok.pem
similarity index 100%
rename from mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLBlacklistValidator-ok.pem
rename to mda-framework/src/test/resources/net/shibboleth/metadata/validate/x509/X509RSAOpenSSLKeylistValidator-ok.pem

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list